@@ -17,6 +17,11 @@ from .enum.pattern import Pattern
 from .enum.trim import Trim
 from .enum.mode import Mode
 from .enum.animation import Animation
-from .messages.message import *
+from .messages.message import formatConnMsg, formatModeMsg, formatDispMsg, formatNameMsg, formatQueryPatternMsg
+from .messages.message import formatUpdatePatternMsg, formatDeletePatternMsg, formatDotMsg
+from .messages.parser import parseOptions, parseQueryData
 
-__version__ = '0.5.0'
+__all__ = ['Pattern', 'Trim', 'Mode', 'Animation', 'formatConnMsg', 'formatModeMsg', 'formatDispMsg', 'formatNameMsg',
+           'formatQueryPatternMsg', 'formatUpdatePatternMsg', 'formatDeletePatternMsg', 'formatDotMsg', 'parseOptions',
+           'parseQueryData', '__version__']
+__version__ = '0.6.0'
